# Installation

The instructions below will help you to properly install the generated package to the lavalite project.

## Location

Extract the package contents to the folder 

`/packages/litecms/rscproduct/`

## Composer

Add the below entries in the `composer.json` file's autoload section and run the command `composer dump-autoload` in terminal.

```json

...
     "autoload": {

        "psr-4": {
            ... ,
            "Litecms\\Rscproduct\\": "packages/litecms/rscproduct/src",
            "Litecms\\Rscproduct\\Seeders\\": "packages/litecms/rscproduct/database/seeders"
            
            ...
        }
    },
...

```

## Config

Add the entries in service provider in `config/app.php`

```php

...
    'providers'       => [
        ...
        
        Litecms\Rscproduct\Providers\RscproductServiceProvider::class,
        
        ...
    ],

    ...

    'alias'             => [
        ...
        
        'Rscproduct'  => Litecms\Rscproduct\Facades\Rscproduct::class,
        
        ...
    ]
...

```

## Migrate

After service provider is set run the commapnd to migrate and seed the database.


    php artisan migrate
    php artisan db:seed --class=Litecms\\Rscproduct\\Seeders\\RscproductTableSeeder

## Publishing


**Publishing configuration**

    php artisan vendor:publish --provider="Litecms\Rscproduct\Providers\RscproductServiceProvider" --tag="config"

**Publishing language**

    php artisan vendor:publish --provider="Litecms\Rscproduct\Providers\RscproductServiceProvider" --tag="lang"

**Publishing views**

    php artisan vendor:publish --provider="Litecms\Rscproduct\Providers\RscproductServiceProvider" --tag="view"


## URLs and APIs


### Web Urls

**Admin**

    http://path-to-route-folder/admin/rscproduct/{modulename}

**User**

    http://path-to-route-folder/user/rscproduct/{modulename}

**Public**

    http://path-to-route-folder/rscproducts


### API endpoints

**List**
 
    http://path-to-route-folder/api/user/rscproduct/{modulename}
    METHOD: GET

**Create**

    http://path-to-route-folder/api/user/rscproduct/{modulename}
    METHOD: POST

**Edit**

    http://path-to-route-folder/api/user/rscproduct/{modulename}/{id}
    METHOD: PUT

**Delete**

    http://path-to-route-folder/api/user/rscproduct/{modulename}/{id}
    METHOD: DELETE

**Public List**

    http://path-to-route-folder/api/rscproduct/{modulename}
    METHOD: GET

**Public Single**

    http://path-to-route-folder/api/rscproduct/{modulename}/{slug}
    METHOD: GET