<?php

namespace Litecms\Rscproduct\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use App\Http\Requests\PublicRequest;
use Litepie\Repository\Filter\RequestFilter;

use Litecms\Rscproduct\Interfaces\ProductRepositoryInterface;
use Litecms\Rscproduct\Repositories\Eloquent\Filters\ProductPublicFilter;
use Litecms\Rscproduct\Repositories\Eloquent\Presenters\ProductListPresenter;

class ProductPublicController extends BaseController
{

    /**
     * Constructor.
     *
     * @return void
     */
    public function __construct(
        ProductRepositoryInterface $product
    ) {
        parent::__construct();
        $this->modules = $this->modules(config('litecms.rscproduct.modules'), 'product', guard_url('product'));
        $this->repository = $product;
    }

    /**
     * Show product's list.
     *
     * @return response
     */
    protected function index(PublicRequest $request)
    {

        $search = $request->search;
        $pageLimit = $request->input('pageLimit', config('database.pagination.limit'));
        $data = $this->repository
            ->pushFilter(RequestFilter::class)
            ->pushFilter(ProductPublicFilter::class)
            ->setPresenter(ProductListPresenter::class)
            ->select('products.*')
            ->paginate($pageLimit)
            ->withQueryString()
            ->toArray();

        extract($data);

        $categories = [];
        $tags = [];
        $recent = [];

        return $this->response->setMetaTitle(trans('rscproduct::product.names'))
            ->view('rscproduct::public.product.index')
            ->data(compact('data', 'meta', 'categories', 'tags', 'recent'))
            ->output();
    }

    /**
     * Show product.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show(PublicRequest $request, $slug)
    {
        $data = $this->repository
            ->findBySlug($slug)
            ->toArray();

        $categories = [];
        $tags = [];
        $recent = [];
    
        return $this->response->setMetaTitle($data['title'] . trans('rscproduct::product.name'))
            ->view('rscproduct::public.product.show')
            ->data(compact('data', 'categories', 'tags', 'recent'))
            ->output();
    }

}
