<?php

namespace Litecms\Rscproduct\Policies;

use Litepie\User\Interfaces\UserPolicyInterface;
use Litecms\Rscproduct\Models\Catalog;

class CatalogPolicy
{

    /**
     * Determine if the given user can view the catalog.
     *
     * @param UserPolicyInterface $authUser
     * @param Catalog $catalog
     *
     * @return bool
     */
    public function view(UserPolicyInterface $authUser, Catalog $catalog)
    {
        if ($authUser->canDo('rscproduct.catalog.view') && $authUser->isAdmin()) {
            return true;
        }

        return $catalog->user_id == user_id() && $catalog->user_type == user_type();
    }

    /**
     * Determine if the given user can create a catalog.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function create(UserPolicyInterface $authUser)
    {
        return  $authUser->canDo('rscproduct.catalog.create');
    }

    /**
     * Determine if the given user can update the given catalog.
     *
     * @param UserPolicyInterface $authUser
     * @param Catalog $catalog
     *
     * @return bool
     */
    public function update(UserPolicyInterface $authUser, Catalog $catalog)
    {
        if ($authUser->canDo('rscproduct.catalog.edit') && $authUser->isAdmin()) {
            return true;
        }

        return $catalog->user_id == user_id() && $catalog->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given catalog.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function destroy(UserPolicyInterface $authUser, Catalog $catalog)
    {
        return $catalog->user_id == user_id() && $catalog->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given catalog.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function verify(UserPolicyInterface $authUser, Catalog $catalog)
    {
        if ($authUser->canDo('rscproduct.catalog.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given catalog.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function approve(UserPolicyInterface $authUser, Catalog $catalog)
    {
        if ($authUser->canDo('rscproduct.catalog.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $authUser    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($authUser, $ability)
    {
        if ($authUser->isSuperuser()) {
            return true;
        }
    }
}
