<?php

namespace Litecms\Rscproduct\Providers;

use Illuminate\Support\ServiceProvider;
use Litecms\Rscproduct\Rscproducts;

class RscproductServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = true;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'rscproduct');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'rscproduct');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerFacade();
        $this->registerBindings();
        //$this->registerCommands();

        $this->app->register(\Litecms\Rscproduct\Providers\AuthServiceProvider::class);
        $this->app->register(\Litecms\Rscproduct\Providers\RouteServiceProvider::class);
        // $this->app->register(\Litecms\Rscproduct\Providers\EventServiceProvider::class);
        // $this->app->register(\Litecms\Rscproduct\Providers\WorkflowServiceProvider::class);
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->bind('litecms.rscproduct', function($app)
        {
            return $this->app->make(Rscproducts::class);
        });
    }

    /**
     * Register the bindings for the service provider.
     *
     * @return void
     */
    public function registerBindings() {
        // Bind Product to repository
        $this->app->bind(
            'Litecms\Rscproduct\Interfaces\ProductRepositoryInterface',
            \Litecms\Rscproduct\Repositories\Eloquent\ProductRepository::class
        );        // Bind Catalog to repository
        $this->app->bind(
            'Litecms\Rscproduct\Interfaces\CatalogRepositoryInterface',
            \Litecms\Rscproduct\Repositories\Eloquent\CatalogRepository::class
        );        // Bind Category to repository
        $this->app->bind(
            'Litecms\Rscproduct\Interfaces\CategoryRepositoryInterface',
            \Litecms\Rscproduct\Repositories\Eloquent\CategoryRepository::class
        );
    }


    /**
     * Merges user's and rscproduct's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/config.php', 'litecms.rscproduct'
        );
    }

    /**
     * Register scaffolding command
     */
    protected function registerCommands()
    {
        if ($this->app->runningInConsole()) {
            $this->commands([
                \Litecms\Rscproduct\Commands\Rscproduct::class,
            ]);
        }
    }
    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['litecms.rscproduct'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('litecms/rscproduct.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/rscproduct')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/rscproduct')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
